Design Écologique
=================

The `Design Écologique`_ website provides permaculture services for
carrying out ecological living projects. It includes resources like
a list of perennial plants relevant to permaculture in Quebec
maintained by the community.

.. _Design Écologique: https://designecologique.ca/
